==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fvlogin-3.10.1-1.2.7.tar.gz: vlogin/data/domains/example.com.vlogin.config.php <==
<?php

  // Global Variables, don't touch these unless you want to break the plugin  
  //
  global $notPartOfDomainName, $numberOfDotSections, $useSessionBased,
         $putHostNameOnFrontOfUsername, $checkByExcludeList,
         $at, $dot, $dontUseHostName, $perUserSettingsFile,
         $smHostIsDomainThatUserLoggedInWith, 
         $useDomainFromServerEnvironment, $virtualDomains,
         $sendmailVirtualUserTable, $virtualDomainDataDir,
         $allVirtualDomainsAreUnderOneHost, $vlogin_debug, $removeFromFront,
         $chopOffDotSectionsFromRight, $chopOffDotSectionsFromLeft,
         $translateHostnameTable, $pathToQmail, $atConversion,
         $removeDomainIfGiven, $alwaysAddHostName, $reverseDotSectionOrder,
         $replacements, $usernameReplacements, $forceLowercase,
         $securePort, $useDomainFromVirtDomainsArray,
         $usernameDomainIsHost, $stripDomainFromUserSubstitution,
         $serviceLevelBackend, $internalServiceLevelFile,
         $vlogin_dsn, $sqlServiceLevelQuery, $SQLDatabaseDomainLookup,
         $SQLDatabaseUserLookup, $SQLDatabaseServiceLevelLookup,
         $default_org_logo, $rawLoginIsOutgoingEmailAddress,
         $dontUseHostNameUserList, $always_prepend, $always_append,
         $IMAPServerRules, $SMTPServerRules, $postProcessingPattern,
         $postProcessingReplacement, $virtualUserTableDBFlavor,
         $override_config_during_login, $appendDomainToOutgoingEmailAddress;


  // list of domain-specific attributes (note that each domain is 
  // specified in this array by any string that is unique to the 
  // virtual host name (not necessarily the whole host name -- 
  // "mydomain" is probably enough to represent "mydomain.com")
  //
  $virtualDomains = array(


//      'domain2' => array(
//          'org_name'   => 'My Domain 2',
//          'org_logo'   => '../images/domain2_image.gif',
//          
//          
//          'org_title'  => '(isset($_SESSION["username"]) ? $_SESSION["username"] . " - Mail" : "Mail")',
//  //  NOTE: The above line is an example of 
//  //        how you can place the user's
//  //        email address in the SquirrelMail
//  //        title bar.
//          
//          
//          'settingsWithEmbeddedPHP' => array(
//                                           'org_title',
//                                      ),   
//  //  NOTE: The above three lines are required when
//  //        using embedded PHP code in the corresponding
//  //        settings as shown above
//      ),


  );


  // turn this on to test your configuration settings - the final
  // IMAP login value will be presented after all processing has
  // been completed
  //
  $vlogin_debug = 0;

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fvlogin-3.10.2-1.2.7.tar.gz: vlogin/data/domains/example.com.vlogin.config.php <==
<?php

  // Global Variables, don't touch these unless you want to break the plugin  
  //
  global $notPartOfDomainName, $numberOfDotSections, $useSessionBased,
         $putHostNameOnFrontOfUsername, $checkByExcludeList,
         $at, $dot, $dontUseHostName, $perUserSettingsFile,
         $smHostIsDomainThatUserLoggedInWith, 
         $useDomainFromServerEnvironment, $virtualDomains,
         $sendmailVirtualUserTable, $virtualDomainDataDir,
         $allVirtualDomainsAreUnderOneHost, $vlogin_debug, $removeFromFront,
         $chopOffDotSectionsFromRight, $chopOffDotSectionsFromLeft,
         $translateHostnameTable, $pathToQmail, $atConversion,
         $removeDomainIfGiven, $alwaysAddHostName, $reverseDotSectionOrder,
         $replacements, $usernameReplacements, $forceLowercase,
         $securePort, $useDomainFromVirtDomainsArray,
         $usernameDomainIsHost, $stripDomainFromUserSubstitution,
         $serviceLevelBackend, $internalServiceLevelFile,
         $vlogin_dsn, $sqlServiceLevelQuery, $SQLDatabaseDomainLookup,
         $SQLDatabaseUserLookup, $SQLDatabaseServiceLevelLookup,
         $default_org_logo, $rawLoginIsOutgoingEmailAddress,
         $dontUseHostNameUserList, $always_prepend, $always_append,
         $IMAPServerRules, $SMTPServerRules, $postProcessingPattern,
         $postProcessingReplacement, $virtualUserTableDBFlavor,
         $override_config_during_login, $appendDomainToOutgoingEmailAddress;


  // list of domain-specific attributes (note that each domain is 
  // specified in this array by any string that is unique to the 
  // virtual host name (not necessarily the whole host name -- 
  // "mydomain" is probably enough to represent "mydomain.com")
  //
//  $virtualDomains = array(
//
//
//      'domain2' => array(
//          'org_name'   => 'My Domain 2',
//          'org_logo'   => '../images/domain2_image.gif',
//          
//          
//          'org_title'  => '(isset($_SESSION["username"]) ? $_SESSION["username"] . " - Mail" : "Mail")',
//  //  NOTE: The above line is an example of 
//  //        how you can place the user's
//  //        email address in the SquirrelMail
//  //        title bar.
//          
//          
//          'settingsWithEmbeddedPHP' => array(
//                                           'org_title',
//                                      ),   
//  //  NOTE: The above three lines are required when
//  //        using embedded PHP code in the corresponding
//  //        settings as shown above
//      ),
//
//
//  );


  // turn this on to test your configuration settings - the final
  // IMAP login value will be presented after all processing has
  // been completed
  //
  $vlogin_debug = 0;
